<?php
add_action( 'admin_init', 'imwb_videopress_theme_options_init' );
add_action( 'admin_menu', 'imwb_videopress_theme_options_add_page' );

/**
 * Init plugin options to white list our options
 */
function imwb_videopress_theme_options_init(){
	register_setting( 'imwb_videopress_options', 'imwb_videopress_theme_options', 'imwb_videopress_theme_options_validate' );
	wp_register_style( 'imwb_videopress-theme-options-stylesheet', get_template_directory_uri().'/admin_options_page.css' );
	wp_register_script( 'imwb_videopress-theme-options-script', get_template_directory_uri().'/scripts/admin_options.js' );
}

/**
 * Load up the menu page
 */
function imwb_videopress_theme_options_add_page() {

	$page = add_theme_page( __( 'Theme Options', 'imwb_videopress' ), __( 'Theme Options', 'imwb_videopress' ), 'edit_theme_options', 'imwb_videopress_theme_options', 'imwb_videopress_theme_options_do_page' );
	
	/* Using registered $page handle to hook stylesheet loading */
   add_action( 'admin_print_styles-' . $page, 'imwb_videopress_admin_styles' );
   add_action( 'admin_print_scripts-' . $page, 'imwb_videopress_admin_scripts' );

}

function imwb_videopress_admin_styles() {
   wp_enqueue_style( 'farbtastic' );
   wp_enqueue_style('imwb_videopress-theme-options-stylesheet');
}

function imwb_videopress_admin_scripts() {
   wp_enqueue_script( 'farbtastic' );
   wp_enqueue_script('imwb_videopress-theme-options-script');
}

/**
 * Returns the default options for Twenty Eleven.
 *
 */
function imwb_videopress_get_default_theme_options() {
	$default_theme_options = array(
	   'faviconurl' => '',
	   'videothumbnw' => 'N',
	   'headerbgcol' => '#FAF7F7',
	   'hideheaderbdr' => 'N',
	   'hidepagemenu' => 'N',
	   'pagemenutype' => '0',
	   'pagemenubgcol' => '#26261E',
  	   'pagemenutxtcol' => '#FFFFFF',
	   'homepagemenu' => 'N',
	   'homepagemenutxt' => 'Home',
	   'excludepages' => '',
	   'hidecatmenu' => 'N',
	   'ravcatmenu' => 'N',
	   'ravcatmenutxt' => 'Recently Added',
	   'ravcatmenutitle' => 'Recently Added Videos',
	   'mvvcatmenu' => 'N',
	   'mvvcatmenutxt' => 'Most Viewed',
	   'mvvcatmenutitle' => 'Most Viewed Videos',
	   'trvcatmenu' => 'N',
	   'trvcatmenutxt' => 'Top Rated',
      'trvcatmenutitle' => 'Top Rated Videos',
	   'othercatmenu' => 'N',
	   'othercatmenutxt' => 'More',
	   'catmenutxtcol' => '#FFFFFF',
  	   'catmenuseltxtcol' => '#000000',
 	   'catmenubgcol' => '#4350D6',
	   'excludecats' => '',
	   'hidesearch' => 'N',
  	   'hidefooter' => 'N',
	   'listorder' => '0',
	   'viewtitle' => '1',
	   'titlecol' => '#040404',
	   'contentbgcol' => '#',
  	   'contentbdrcol' => '#',
		'homesidebar' => '2',
		'homesidebarbgcol' => '#F9F9F9',
		'homesidebarbdrcol' => '#C6C6C6',
		'widgettitlebgcol' => '#C6C6C6',
		'widgettitletxtcol' => '#040404',
		'showtitle' => '1',
		'postcontent' => 'F',
		'postchars' => '100',
		'commentstats' => '1',
		'showcomments' => '0',
		'viewstats' => '1',
		'viewrating' => '1',
		'commentcount' => '0',
		'ptcontentbdrcol' => '#CCCACA',
		'hidepttitle' => 'N',
		'hideptdetails' => 'N',
		'hideptcomments' => 'N',
		'hideptviewstats' => 'N',
		'hideptsocialbtns' => 'N',
		'hideptrating' => 'N',
		'hidepttagstats' => 'N',
		'hideptcatstats' => 'N',
		'pagesidebar' => '0',
		'postsidebar' => '2',
		'hidepgtitle' => 'N',
		'hidepgdetails' => 'N',
		'hidepgcomments' => 'N',
		'footerbgcol' => '#FAF7F7',
   	'footerbdrcol' => '#dddddd',
   	'autoplay' => '1',
   	'autogenthumbs' => '1',
   	'storethumbs' => '0',
   	'ytmodestbrand' => '0'
	);

	return $default_theme_options;
}

$sidebar_options = array(
	'0' => array('label' => __('Off', 'imwb_videopress')),
	'1' => array('label' => __('Left', 'imwb_videopress')),
	'2' => array('label' => __('Right', 'imwb_videopress'))
);

$yesno_options = array(
	'1' => array('label' => __('Yes', 'imwb_videopress')),
	'0' => array('label' => __('No', 'imwb_videopress'))
);

$listorder_options = array(
	'0' => array('label' => __('Newest', 'imwb_videopress')),
	'1' => array('label' => __('Top Rated', 'imwb_videopress')),	
	'2' => array('label' => __('Most Viewed', 'imwb_videopress'))
);

$pagemenu_options = array(
	'0' => array('label' => __('Page Menu', 'imwb_videopress')),
	'1' => array('label' => __('Custom Menu', 'imwb_videopress'))
);

// Function to get a list of the Blogs pages and return a <option> list of them
function cvp_get_blog_pages($parentId = 0, $selected=array(), $level = 0) {
   $retStr = '';

   if(!is_array($selected))
      $selected = array();
   
   $pages = get_pages('parent='.$parentId.'&child_of='.$parentId);
   if(count($pages) > 0){
      foreach($pages as $page){
        $sel = false;
        if(in_array($page->ID,$selected))
        		$sel = true;    
        $retStr.= "<option value='" . $page->ID . "' ".(($sel)?' selected="selected"':'').'>'.str_repeat('  - ', $level).wp_specialchars($page->post_title).'</option>'.cvp_get_blog_pages($page->ID, $selected, $level+1);
      }
   }
   
   return $retStr;
}

// Function to get a list of the Blogs Categories and return a <option> list of them
function cvp_get_blog_categories($parentId = 0, $selected=array(), $level = 0) {
   $retStr = '';

   if(!is_array($selected))
      $selected = array();
   
	$cats = get_categories('child_of='.$parentId.'&parent='.$parentId.'&hide_empty=0');
   if(count($cats) > 0){
      foreach($cats as $cat){
        $sel = false;
        if(in_array($cat->cat_ID,$selected))
        		$sel = true;    
        $retStr.= "<option value='" . $cat->cat_ID . "' ".(($sel)?' selected="selected"':'').'>'.str_repeat('  - ', $level).wp_specialchars($cat->cat_name).'</option>'.cvp_get_blog_categories($cat->cat_ID, $selected, $level+1);
      }
   }
   
   return $retStr;
}

/**
 * Create the options page
 */
function imwb_videopress_theme_options_do_page() {
   global $sidebar_options, $yesno_options, $listorder_options, $pagemenu_options;
   
	?>
	
	<div class="wrap">
	<div id="imwb_plugin_header">
	<a href="http://imwealthbuilders.com" target="_blank"><img src="<?php echo get_template_directory_uri(). '/images/imwblogo.png';?>"></a>
	<span id="imwb_plugin_header_link"><a href="http://imwealthbuilders.com/newplugins" target="_blank">Click Here To See Our Latest WP Plugins</a></span>
	<h2>Covert VideoPress Theme</h2>
	<div style="clear: both"></div>
	</div>
   <?php if(isset($_REQUEST['page']) && $_REQUEST['page'] == 'imwb_videopress_theme_options' && isset($_REQUEST['action']) && $_REQUEST['action'] == 'update') : ?>
      <div class="imwb_cabar_active_panel"><p><strong><?php _e( 'Options saved', 'imwb_videopress' ); ?></strong></p></div>
   <?php endif; ?>
	<div id="imwb_plugin_options_editor">
		
		<?php screen_icon(); echo "<h2>" . __( 'Theme Options', 'imwb_videopress' ) . ' - <small><a href="http://covertvideopress.com/help/std_help.html" target="_blank">Click Here For Help</a></small></h2>'; ?>

		<form method="post" action="" enctype="multipart/form-data">
			<?php settings_fields( 'imwb_videopress_options' ); ?>
         <br>
         <table class="widefat">
          <thead>
           <tr>
            <th scope="col" colspan="2">General Options</th>
           </tr>
          </thead>
           <tbody style="display: table-row-group;">
 				<tr valign="top"><td width="350px"><?php _e( 'Favicon', 'imwb_videopress' ); ?></td>
 					<td>
 						<input id="imwb_videopress_theme_options[faviconurl]" class="regular-text" type="text" name="imwb_videopress_theme_options[faviconurl]" value="<?php esc_attr_e( imwb_videopress_get_option('faviconurl') ); ?>" />
 						<label class="description" for="imwb_videopress_theme_options[faviconurl]"><?php _e( 'Favicon url [16x16]', 'imwb_videopress' ); ?></label><br>
 						<input type="file" name="favicon_img"  id="favicon_img" />
 					</td>
 				</tr>
 				<tr><td width="350px"><?php _e( 'When Clicking a Video Thumb Open Video in New Window', 'imwb_videopress' ); ?></td>
 					 <td><input id="imwb_videopress_theme_options[videothumbnw]" type="checkbox" name="imwb_videopress_theme_options[videothumbnw]" value="Y" <?php echo imwb_videopress_get_option('videothumbnw') == "Y" ? "checked='Yes'" : "" ?> />
 						
 					</td>
 				</tr>
          </tbody>
 			</table>
 <br>
         <table class="widefat">
          <thead>
           <tr>
            <th scope="col" colspan="2">Header & Navigation Menus</th>
           </tr>
          </thead>
           <tbody style="display: table-row-group;">
           <tr><td width="350px"><?php _e( 'Header Background Color', 'imwb_videopress' ); ?></td>
           	 <td>
           	   <input class="color-input" type="text" name="imwb_videopress_theme_options[headerbgcol]" value="<?php echo esc_attr( imwb_videopress_get_option('headerbgcol') ); ?>"/>
           	   <input type='button' class='pickcolor button-secondary' value='Select Color'>
           	   <div style='z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;'></div>
           	</td>
           </tr>
           <tr><td width="350px"><?php _e( 'Hide Header/Content Divider Line', 'imwb_videopress' ); ?></td>
           	 <td><input id="imwb_videopress_theme_options[hideheaderbdr]" type="checkbox" name="imwb_videopress_theme_options[hideheaderbdr]" value="Y" <?php echo imwb_videopress_get_option('hideheaderbdr') == "Y" ? "checked='Yes'" : "" ?> />
           		
           	</td>
           </tr>
           <tr><td colspan="2"><strong><?php _e( 'Pages Menu', 'imwb_videopress' ); ?></strong></td></tr>
           <tr><td width="350px"><?php _e( 'Hide Page Menu', 'imwb_videopress' ); ?></td>
           	 <td><input id="imwb_videopress_theme_options[hidepagemenu]" type="checkbox" name="imwb_videopress_theme_options[hidepagemenu]" value="Y" <?php echo imwb_videopress_get_option('hidepagemenu') == "Y" ? "checked='Yes'" : "" ?> />
           		
           	</td>
           </tr>
           <tr><td width="350px"><?php _e( 'Text Color', 'imwb_videopress' ); ?></td>
           	 <td>
           	   <input class="color-input" type="text" name="imwb_videopress_theme_options[pagemenutxtcol]" value="<?php echo esc_attr( imwb_videopress_get_option('pagemenutxtcol') ); ?>"/>
           	   <input type='button' class='pickcolor button-secondary' value='Select Color'>
           	   <div style='z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;'></div>
           	</td>
           </tr>
           <tr><td width="350px"><?php _e( 'Background Color', 'imwb_videopress' ); ?></td>
           	 <td>
           	   <input class="color-input" type="text" name="imwb_videopress_theme_options[pagemenubgcol]" value="<?php echo esc_attr( imwb_videopress_get_option('pagemenubgcol') ); ?>"/>
           	   <input type='button' class='pickcolor button-secondary' value='Select Color'>
           	   <div style='z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;'></div>
           	</td>
           </tr>
           
           <tr><td width="350px"><?php _e( 'Use Standard Page Menu or Custom Menu', 'imwb_videopress' ); ?></td>
           	 <td>
               <select id="imwb_videopress_theme_options[pagemenutype]" class="regular-text" type="text" name="imwb_videopress_theme_options[pagemenutype]" />
               <?php 
                foreach ($pagemenu_options as $key => $value) {
                   $selected = (imwb_videopress_get_option('pagemenutype') == $key) ? " selected" : "";
                   echo "<option value='{$key}'{$selected}>{$value['label']}</option>";
                }
               ?>
               </select>
           	</td>
           </tr>
           
           <tr class="pgmenutype_custom" <?php echo imwb_videopress_get_option('pagemenutype') == '0' ? 'style="display: none;"' : ""; ?> ><td></td><td>Use the Appearance->Menus option to create/edit the custom menu</td></tr>
           
           <tr class="pgmenutype_std" <?php echo imwb_videopress_get_option('pagemenutype') == '1' ? 'style="display: none;"' : ""; ?>><td width="350px"><?php _e( 'Home Menu Option', 'imwb_videopress' ); ?></td>
           	 <td>Menu Text <input type="text" name="imwb_videopress_theme_options[homepagemenutxt]" value="<?php echo esc_attr( imwb_videopress_get_option('homepagemenutxt') ); ?>" size="30"/> - Don't Show <input id="imwb_videopress_theme_options[homepagemenu]" type="checkbox" name="imwb_videopress_theme_options[homepagemenu]" value="Y" <?php echo imwb_videopress_get_option('homepagemenu') == "Y" ? "checked='Yes'" : "" ?> /> 
           		
           	</td>
           </tr>
            <tr class="pgmenutype_std" <?php echo imwb_videopress_get_option('pagemenutype') == '1' ? 'style="display: none;"' : ""; ?>><td width="350px"><?php _e( 'Pages to Exclude', 'imwb_videopress' ); ?></td>
            	 <td><select size="10"  multiple="multiple"  style="width:340px; height:auto;" name="imwb_videopress_theme_options[excludepages][]" id="imwb_videopress_theme_options[excludepages]" >
				<?php
							$currentpages = explode(",", htmlspecialchars(imwb_videopress_get_option('excludepages')) );
                     echo cvp_get_blog_pages(0, $currentpages);
							
				?></select>   <br>
				<a href="javascript:void(0)" onclick="imwb_ms_unselectAll(document.getElementById('imwb_videopress_theme_options[excludepages]'))"><?php _e('Unselect All','imwb_videopress'); ?></a>         	 
            	 </td>
            </tr>
            <tr><td colspan="2"><strong><?php _e( 'Category Menu', 'imwb_videopress' ); ?></strong></td></tr>
            <tr><td width="350px"><?php _e( 'Hide Category Menu', 'imwb_videopress' ); ?></td>
            	 <td><input id="imwb_videopress_theme_options[hidecatmenu]" type="checkbox" name="imwb_videopress_theme_options[hidecatmenu]" value="Y" <?php echo imwb_videopress_get_option('hidecatmenu') == "Y" ? "checked='Yes'" : "" ?> />
            		
            	</td>
            </tr>
            <tr><td width="350px"><?php _e( 'Text Color', 'imwb_videopress' ); ?></td>
            	 <td>
            	   <input class="color-input" type="text" name="imwb_videopress_theme_options[catmenutxtcol]" value="<?php echo esc_attr( imwb_videopress_get_option('catmenutxtcol') ); ?>"/>
            	   <input type='button' class='pickcolor button-secondary' value='Select Color'>
            	   <div style='z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;'></div>
            	</td>
            </tr>
            <tr><td width="350px"><?php _e( 'Selected Menu Text Color', 'imwb_videopress' ); ?></td>
            	 <td>
            	   <input class="color-input" type="text" name="imwb_videopress_theme_options[catmenuseltxtcol]" value="<?php echo esc_attr( imwb_videopress_get_option('catmenuseltxtcol') ); ?>"/>
            	   <input type='button' class='pickcolor button-secondary' value='Select Color'>
            	   <div style='z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;'></div>
            	</td>
            </tr>
            <tr><td width="350px"><?php _e( 'Background Color', 'imwb_videopress' ); ?></td>
            	 <td>
            	   <input class="color-input" type="text" name="imwb_videopress_theme_options[catmenubgcol]" value="<?php echo esc_attr( imwb_videopress_get_option('catmenubgcol') ); ?>"/>
            	   <input type='button' class='pickcolor button-secondary' value='Select Color'>
            	   <div style='z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;'></div>
            	</td>
            </tr>
            <tr><td width="350px"><?php _e( 'Recently Added Videos Menu Option', 'imwb_videopress' ); ?></td>
            	 <td>Menu Text <input type="text" name="imwb_videopress_theme_options[ravcatmenutxt]" value="<?php echo esc_attr( imwb_videopress_get_option('ravcatmenutxt') ); ?>" size="30"/> - Don't Show <input id="imwb_videopress_theme_options[ravcatmenu]" type="checkbox" name="imwb_videopress_theme_options[ravcatmenu]" value="Y" <?php echo imwb_videopress_get_option('ravcatmenu') == "Y" ? "checked='Yes'" : "" ?> /><br>
            	   Title Text&nbsp;&nbsp;&nbsp;<input type="text" name="imwb_videopress_theme_options[ravcatmenutitle]" value="<?php echo esc_attr( imwb_videopress_get_option('ravcatmenutitle') ); ?>" size="30"/>
            		
            	</td>
            </tr>            
            <tr><td width="350px"><?php _e( 'Most Viewed Videos Menu Option', 'imwb_videopress' ); ?></td>
            	 <td>Menu Text <input type="text" name="imwb_videopress_theme_options[mvvcatmenutxt]" value="<?php echo esc_attr( imwb_videopress_get_option('mvvcatmenutxt') ); ?>" size="30"/> - Don't Show <input id="imwb_videopress_theme_options[mvvcatmenu]" type="checkbox" name="imwb_videopress_theme_options[mvvcatmenu]" value="Y" <?php echo imwb_videopress_get_option('mvvcatmenu') == "Y" ? "checked='Yes'" : "" ?> /><br>
            	   Title Text&nbsp;&nbsp;&nbsp;<input type="text" name="imwb_videopress_theme_options[mvvcatmenutitle]" value="<?php echo esc_attr( imwb_videopress_get_option('mvvcatmenutitle') ); ?>" size="30"/>
            	</td>
            </tr>  
            <tr><td width="350px"><?php _e( 'Top Rated Videos Menu Option', 'imwb_videopress' ); ?></td>
            	 <td>Menu Text <input type="text" name="imwb_videopress_theme_options[trvcatmenutxt]" value="<?php echo esc_attr( imwb_videopress_get_option('trvcatmenutxt') ); ?>" size="30"/> - Don't Show <input id="imwb_videopress_theme_options[trvcatmenu]" type="checkbox" name="imwb_videopress_theme_options[trvcatmenu]" value="Y" <?php echo imwb_videopress_get_option('trvcatmenu') == "Y" ? "checked='Yes'" : "" ?> /><br>
            	   Title Text&nbsp;&nbsp;&nbsp;<input type="text" name="imwb_videopress_theme_options[trvcatmenutitle]" value="<?php echo esc_attr( imwb_videopress_get_option('trvcatmenutitle') ); ?>" size="30"/>
            	</td>
            </tr>  
            <tr><td width="350px"><?php _e( 'Other Categories Drop Down Menu Option', 'imwb_videopress' ); ?></td>
            	 <td>Menu Text <input type="text" name="imwb_videopress_theme_options[othercatmenutxt]" value="<?php echo esc_attr( imwb_videopress_get_option('othercatmenutxt') ); ?>" size="30"/> - Don't Show <input id="imwb_videopress_theme_options[othercatmenu]" type="checkbox" name="imwb_videopress_theme_options[othercatmenu]" value="Y" <?php echo imwb_videopress_get_option('othercatmenu') == "Y" ? "checked='Yes'" : "" ?> />
            	</td>
            </tr>  
            <tr><td width="350px"><?php _e( 'Categories to Exclude from Drop Down Menu', 'imwb_videopress' ); ?></td>
            	 <td><select size="10"  multiple="multiple"  style="width:340px; height:auto;" name="imwb_videopress_theme_options[excludecats][]" id="imwb_videopress_theme_options[excludecats]" >
				<?php
							$currentcats = explode(",", htmlspecialchars(imwb_videopress_get_option('excludecats')) );
                     echo cvp_get_blog_categories(0, $currentcats);
							
				?></select>   <br>
				<a href="javascript:void(0)" onclick="imwb_ms_unselectAll(document.getElementById('imwb_videopress_theme_options[excludecats]'))"><?php _e('Unselect All','imwb_videopress'); ?></a>         	 
            	 </td>
            </tr>
            <tr><td width="350px"><?php _e( 'Hide Search Form', 'imwb_videopress' ); ?></td>
            	 <td><input id="imwb_videopress_theme_options[hidesearch]" type="checkbox" name="imwb_videopress_theme_options[hidesearch]" value="Y" <?php echo imwb_videopress_get_option('hidesearch') == "Y" ? "checked='Yes'" : "" ?> />
            		
            	</td>
            </tr>
            <tr><td width="350px"><?php _e( 'Hide Footer', 'imwb_videopress' ); ?></td>
             	 <td><input id="imwb_videopress_theme_options[hidefooter]" type="checkbox" name="imwb_videopress_theme_options[hidefooter]" value="Y" <?php echo imwb_videopress_get_option('hidefooter') == "Y" ? "checked='Yes'" : "" ?> />
             		
             	</td>
            </tr>           
          </tbody>
 			</table>
 <br>
        <table class="widefat">
         <thead>
          <tr>
           <th scope="col" colspan="2">Sidebar & Widgets Options</th>
          </tr>
         </thead>
          <tbody style="display: table-row-group;">
          <tr><td width="350px"><?php _e( 'Sidebar Widget Background Color', 'imwb_videopress' ); ?></td>
          	 <td>
          	   <input class="color-input" type="text" name="imwb_videopress_theme_options[homesidebarbgcol]" value="<?php echo esc_attr( imwb_videopress_get_option('homesidebarbgcol') ); ?>"/>
          	   <input type='button' class='pickcolor button-secondary' value='Select Color'>
          	   <div style='z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;'></div>
          	</td>
          </tr>
          <tr><td width="350px"><?php _e( 'Sidebar Widget Border Color', 'imwb_videopress' ); ?></td>
          	 <td>
          	   <input class="color-input" type="text" name="imwb_videopress_theme_options[homesidebarbdrcol]" value="<?php echo esc_attr( imwb_videopress_get_option('homesidebarbdrcol') ); ?>"/>
          	   <input type='button' class='pickcolor button-secondary' value='Select Color'>
          	   <div style='z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;'></div>
          	</td>
          </tr>				
          <tr><td width="350px"><?php _e( 'Widget Title Background Color', 'imwb_videopress' ); ?></td>
          	 <td>
          	   <input class="color-input" type="text" name="imwb_videopress_theme_options[widgettitlebgcol]" value="<?php echo esc_attr( imwb_videopress_get_option('widgettitlebgcol') ); ?>"/>
          	   <input type='button' class='pickcolor button-secondary' value='Select Color'>
          	   <div style='z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;'></div>
          	</td>
          </tr>
          <tr><td width="350px"><?php _e( 'Widget Title Text Color', 'imwb_videopress' ); ?></td>
          	 <td>
          	   <input class="color-input" type="text" name="imwb_videopress_theme_options[widgettitletxtcol]" value="<?php echo esc_attr( imwb_videopress_get_option('widgettitletxtcol') ); ?>"/>
          	   <input type='button' class='pickcolor button-secondary' value='Select Color'>
          	   <div style='z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;'></div>
          	</td>
          </tr>
         </tbody>
			</table>
<br>
			<table class="widefat">
          <thead>
           <tr>
            <th scope="col" colspan="2">Home Page</th>
           </tr>
          </thead>
          <tbody style="display: table-row-group;">
          <tr valign="top"><td width="350px"><?php _e( 'Default Video Listing Order', 'imwb_videopress' ); ?></td>
          	<td>
          		<select id="imwb_videopress_theme_options[listorder]" class="regular-text" type="text" name="imwb_videopress_theme_options[listorder]" />
          		<?php 
          		 foreach ($listorder_options as $key => $value) {
                    $selected = (imwb_videopress_get_option('listorder') == $key) ? " selected" : "";
          		    echo "<option value='{$key}'{$selected}>{$value['label']}</option>";
          		 }
          		?>
          		</select>
          	</td>
          </tr>
          <tr valign="top"><td width="350px"><?php _e( 'Show Title', 'imwb_videopress' ); ?></td>
          	<td>
          		<select id="imwb_videopress_theme_options[viewtitle]" class="regular-text" type="text" name="imwb_videopress_theme_options[viewtitle]" />
          		<?php 
          		 foreach ($yesno_options as $key => $value) {
                    $selected = (imwb_videopress_get_option('viewtitle') == $key) ? " selected" : "";
          		    echo "<option value='{$key}'{$selected}>{$value['label']}</option>";
          		 }
          		?>
          		</select>
          	</td>
          </tr>
          <tr><td width="350px"><?php _e( 'Title Text Color', 'imwb_videopress' ); ?></td>
          	 <td>
          	   <input class="color-input" type="text" name="imwb_videopress_theme_options[titlecol]" value="<?php echo esc_attr( imwb_videopress_get_option('titlecol') ); ?>"/>
          	   <input type='button' class='pickcolor button-secondary' value='Select Color'>
          	   <div style='z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;'></div>
          	</td>
          </tr>
          <tr><td width="350px"><?php _e( 'Content Area Background Color', 'imwb_videopress' ); ?></td>
          	 <td>
          	   <input class="color-input" type="text" name="imwb_videopress_theme_options[contentbgcol]" value="<?php echo esc_attr( imwb_videopress_get_option('contentbgcol') ); ?>"/>
          	   <input type='button' class='pickcolor button-secondary' value='Select Color'>
          	   <div style='z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;'></div>
          	</td>
          </tr>
         <tr><td width="350px"><?php _e( 'Content Area Border Color', 'imwb_videopress' ); ?></td>
         	 <td>
         	   <input class="color-input" type="text" name="imwb_videopress_theme_options[contentbdrcol]" value="<?php echo esc_attr( imwb_videopress_get_option('contentbdrcol') ); ?>"/>
         	   <input type='button' class='pickcolor button-secondary' value='Select Color'>
         	   <div style='z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;'></div>
         	</td>
         </tr>
				<tr valign="top"><td width="350px"><?php _e( 'Main Sidebar Widget', 'imwb_videopress' ); ?></td>
					<td>
						<select id="imwb_videopress_theme_options[homesidebar]" class="regular-text" type="text" name="imwb_videopress_theme_options[homesidebar]" />
						<?php 
						 foreach ($sidebar_options as $key => $value) {
                      $selected = (imwb_videopress_get_option('homesidebar') == $key) ? " selected" : "";
						    echo "<option value='{$key}'{$selected}>{$value['label']}</option>";
						 }
						?>
						</select>
					</td>
				</tr>
				<tr valign="top"><td width="350px"><?php _e( 'Show Post Title', 'imwb_videopress' ); ?></td>
					<td>
						<select id="imwb_videopress_theme_options[showtitle]" class="regular-text" type="text" name="imwb_videopress_theme_options[showtitle]" />
						<?php 
						 foreach ($yesno_options as $key => $value) {
				          $selected = (imwb_videopress_get_option('showtitle') == $key) ? " selected" : "";
						    echo "<option value='{$key}'{$selected}>{$value['label']}</option>";
						 }
						?>
						</select>
					</td>
				</tr>
				
				<tr valign="top"><td width="350px"><?php _e( 'Post Content', 'imwb_videopress' ); ?></td>
					<td><input id="imwb_videopress_theme_options[postcontent]" type="radio" name="imwb_videopress_theme_options[postcontent]" value="N" <?php echo imwb_videopress_get_option('postcontent') == "N" ? "checked='Yes'" : "" ?> /> Don't show post content.<br class="clear">
					<input id="imwb_videopress_theme_options[postcontent]" type="radio" name="imwb_videopress_theme_options[postcontent]" value="F" <?php echo imwb_videopress_get_option('postcontent') == "F" ? "checked='Yes'" : "" ?> /> Show full post text<br class="clear">
					<input id="imwb_videopress_theme_options[postcontent]" type="radio" name="imwb_videopress_theme_options[postcontent]" value="E" <?php echo imwb_videopress_get_option('postcontent') == "E" ? "checked='Yes'" : "" ?> /> Show the post excerpt - If no explicit excerpt for a post, an automatic excerpt of the first 55 words of content will be used<br>
					<input id="imwb_videopress_theme_options[postcontent]" type="radio" name="imwb_videopress_theme_options[postcontent]" value="C" <?php echo imwb_videopress_get_option('postcontent') == "C" ? "checked='Yes'" : "" ?> /> Custom post excerpt - Show the first <input type="text" name="imwb_videopress_theme_options[postchars]" value="<?php echo imwb_videopress_get_option('postchars');?>" size=5 <?php echo imwb_videopress_get_option('postcontent') != "C" ? "readonly" : "" ?>> characters of the post content.
					</td>
				</tr>
				<tr valign="top"><td width="350px"><?php _e( 'Show Rating', 'imwb_videopress' ); ?></td>
					<td>
						<select id="imwb_videopress_theme_options[viewrating]" class="regular-text" type="text" name="imwb_videopress_theme_options[viewrating]" />
						<?php 
						 foreach ($yesno_options as $key => $value) {
				          $selected = (imwb_videopress_get_option('viewrating') == $key) ? " selected" : "";
						    echo "<option value='{$key}'{$selected}>{$value['label']}</option>";
						 }
						?>
						</select>
					</td>
				</tr>
				<tr valign="top"><td width="350px"><?php _e( 'Show View Count', 'imwb_videopress' ); ?></td>
					<td>
						<select id="imwb_videopress_theme_options[viewstats]" class="regular-text" type="text" name="imwb_videopress_theme_options[viewstats]" />
						<?php 
						 foreach ($yesno_options as $key => $value) {
				          $selected = (imwb_videopress_get_option('viewstats') == $key) ? " selected" : "";
						    echo "<option value='{$key}'{$selected}>{$value['label']}</option>";
						 }
						?>
						</select>
					</td>
				</tr>
            <tr valign="top"><td width="350px"><?php _e( 'Show Comment Count', 'imwb_videopress' ); ?></td>
            	<td>
            		<select id="imwb_videopress_theme_options[commentstats]" class="regular-text" type="text" name="imwb_videopress_theme_options[commentstats]" />
            		<?php 
            		 foreach ($yesno_options as $key => $value) {
                      $selected = (imwb_videopress_get_option('commentstats') == $key) ? " selected" : "";
            		    echo "<option value='{$key}'{$selected}>{$value['label']}</option>";
            		 }
            		?>
            		</select>
            	</td>
            </tr>
            <tr valign="top"><td width="350px"><?php _e( 'Show Comments', 'imwb_videopress' ); ?></td>
            	<td>
            		<select id="imwb_videopress_theme_options[showcomments]" class="regular-text" type="text" name="imwb_videopress_theme_options[showcomments]" />
            		<?php 
            		 foreach ($yesno_options as $key => $value) {
                      $selected = (imwb_videopress_get_option('showcomments') == $key) ? " selected" : "";
            		    echo "<option value='{$key}'{$selected}>{$value['label']}</option>";
            		 }
            		?>
            		</select><span id="commentcount" <?php echo imwb_videopress_get_option('showcomments') == 0 ? "style='display:none;'" : "" ?>> Show at most <input type="text" name="imwb_videopress_theme_options[commentcount]" value="<?php echo imwb_videopress_get_option('commentcount');?>" size=4> comments (0 = show all)</span>
            	</td>
            </tr>
        </tbody>
			</table>
<br>
			<table class="widefat">
         <thead>
          <tr>
           <th scope="col" colspan="2">Posts and Pages</th>
          </tr>
         </thead>
         <tbody style="display: table-row-group;">
         <tr><td width="350px"><?php _e( 'Content Area Border Color', 'imwb_videopress' ); ?></td>
         	 <td>
         	   <input class="color-input" type="text" name="imwb_videopress_theme_options[ptcontentbdrcol]" value="<?php echo esc_attr( imwb_videopress_get_option('ptcontentbdrcol') ); ?>"/>
         	   <input type='button' class='pickcolor button-secondary' value='Select Color'>
         	   <div style='z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;'></div>
         	</td>
         </tr>
         <tr><td colspan="2"><strong><?php _e( 'Posts', 'imwb_videopress' ); ?></strong></td>
         </tr>
         <tr valign="top"><td width="350px"><?php _e( 'Post Sidebar Widget', 'imwb_videopress' ); ?></td>
         	<td>
         		<select id="imwb_videopress_theme_options[postsidebar]" class="regular-text" type="text" name="imwb_videopress_theme_options[postsidebar]" />
         		<?php 
         		 foreach ($sidebar_options as $key => $value) {
                   $selected = (imwb_videopress_get_option('postsidebar') == $key) ? " selected" : "";
         		    echo "<option value='{$key}'{$selected}>{$value['label']}</option>";
         		 }
         		?>
         		</select>
         	</td>
         </tr>
           <tr><td width="350px"><?php _e( 'Hide Title', 'imwb_videopress' ); ?></td>
            		 <td><input id="imwb_videopress_theme_options[hidepttitle]" type="checkbox" name="imwb_videopress_theme_options[hidepttitle]" value="Y" <?php echo imwb_videopress_get_option('hidepttitle') == "Y" ? "checked='Yes'" : "" ?> />
            			
            		</td>
           </tr>
           <tr><td width="350px"><?php _e( 'Hide Uploaded Details', 'imwb_videopress' ); ?></td>
           		 <td><input id="imwb_videopress_theme_options[hideptdetails]" type="checkbox" name="imwb_videopress_theme_options[hideptdetails]" value="Y" <?php echo imwb_videopress_get_option('hideptdetails') == "Y" ? "checked='Yes'" : "" ?> />
           			
           		</td>
           </tr>     
           <tr><td width="350px"><?php _e( 'Hide Social Buttons', 'imwb_videopress' ); ?></td>
            		 <td><input id="imwb_videopress_theme_options[hideptsocialbtns]" type="checkbox" name="imwb_videopress_theme_options[hideptsocialbtns]" value="Y" <?php echo imwb_videopress_get_option('hideptsocialbtns') == "Y" ? "checked='Yes'" : "" ?> />
            			
            		</td>
           </tr> 
            <tr><td width="350px"><?php _e( 'Hide Rating', 'imwb_videopress' ); ?></td>
             		 <td><input id="imwb_videopress_theme_options[hideptrating]" type="checkbox" name="imwb_videopress_theme_options[hideptrating]" value="Y" <?php echo imwb_videopress_get_option('hideptrating') == "Y" ? "checked='Yes'" : "" ?> />
             			
             		</td>
            </tr>               
            <tr><td width="350px"><?php _e( 'Hide Views Count', 'imwb_videopress' ); ?></td>
             		 <td><input id="imwb_videopress_theme_options[hideptviewstats]" type="checkbox" name="imwb_videopress_theme_options[hideptviewstats]" value="Y" <?php echo imwb_videopress_get_option('hideptviewstats') == "Y" ? "checked='Yes'" : "" ?> />
             			
             		</td>
            </tr>
            <tr><td width="350px"><?php _e( 'Hide Tags', 'imwb_videopress' ); ?></td>
             		 <td><input id="imwb_videopress_theme_options[hidepttagstats]" type="checkbox" name="imwb_videopress_theme_options[hidepttagstats]" value="Y" <?php echo imwb_videopress_get_option('hidepttagstats') == "Y" ? "checked='Yes'" : "" ?> />
             			
             		</td>
            </tr>            
            <tr><td width="350px"><?php _e( 'Hide Categories', 'imwb_videopress' ); ?></td>
             		 <td><input id="imwb_videopress_theme_options[hideptcatstats]" type="checkbox" name="imwb_videopress_theme_options[hideptcatstats]" value="Y" <?php echo imwb_videopress_get_option('hideptcatstats') == "Y" ? "checked='Yes'" : "" ?> />
             			
             		</td>
            </tr>    
            <tr><td width="350px"><?php _e( 'Hide Comments', 'imwb_videopress' ); ?></td>
             		 <td><input id="imwb_videopress_theme_options[hideptcomments]" type="checkbox" name="imwb_videopress_theme_options[hideptcomments]" value="Y" <?php echo imwb_videopress_get_option('hideptcomments') == "Y" ? "checked='Yes'" : "" ?> />
             			
             		</td>
            </tr>                             
            </tr>
              <tr><td colspan="2"><strong><?php _e( 'Pages', 'imwb_videopress' ); ?></strong></td>
              </tr>
              <tr valign="top"><td width="350px"><?php _e( 'Main Sidebar Widget', 'imwb_videopress' ); ?></td>
              	<td>
              		<select id="imwb_videopress_theme_options[pagesidebar]" class="regular-text" type="text" name="imwb_videopress_theme_options[pagesidebar]" />
              		<?php 
              		 foreach ($sidebar_options as $key => $value) {
                        $selected = (imwb_videopress_get_option('pagesidebar') == $key) ? " selected" : "";
              		    echo "<option value='{$key}'{$selected}>{$value['label']}</option>";
              		 }
              		?>
              		</select>
              	</td>
              </tr>
              <tr><td width="350px"><?php _e( 'Hide Title', 'imwb_videopress' ); ?></td>
               		 <td><input id="imwb_videopress_theme_options[hidepgtitle]" type="checkbox" name="imwb_videopress_theme_options[hidepgtitle]" value="Y" <?php echo imwb_videopress_get_option('hidepgtitle') == "Y" ? "checked='Yes'" : "" ?> />
               			
               		</td>
              </tr>
              <tr><td width="350px"><?php _e( 'Hide Created Details', 'imwb_videopress' ); ?></td>
              		 <td><input id="imwb_videopress_theme_options[hidepgdetails]" type="checkbox" name="imwb_videopress_theme_options[hidepgdetails]" value="Y" <?php echo imwb_videopress_get_option('hidepgdetails') == "Y" ? "checked='Yes'" : "" ?> />
              			
              		</td>
              </tr>     
              <tr><td width="350px"><?php _e( 'Hide Comments', 'imwb_videopress' ); ?></td>
               		 <td><input id="imwb_videopress_theme_options[hidepgcomments]" type="checkbox" name="imwb_videopress_theme_options[hidepgcomments]" value="Y" <?php echo imwb_videopress_get_option('hidepgcomments') == "Y" ? "checked='Yes'" : "" ?> />
               			
               		</td>
              </tr>                  

          </tbody>
         </table>
         <br>
         	<table class="widefat">
           <thead>
            <tr>
             <th scope="col" colspan="2">Footer</th>
            </tr>
           </thead>
           <tbody style="display: table-row-group;">
           <tr><td width="350px"><?php _e( 'Footer Area Background Color', 'imwb_videopress' ); ?></td>
           	 <td>
           	   <input class="color-input" type="text" name="imwb_videopress_theme_options[footerbgcol]" value="<?php echo esc_attr( imwb_videopress_get_option('footerbgcol') ); ?>"/>
           	   <input type='button' class='pickcolor button-secondary' value='Select Color'>
           	   <div style='z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;'></div>
           	</td>
           </tr>
          <tr><td width="350px"><?php _e( 'Footer Area Border Color', 'imwb_videopress' ); ?></td>
          	 <td>
          	   <input class="color-input" type="text" name="imwb_videopress_theme_options[footerbdrcol]" value="<?php echo esc_attr( imwb_videopress_get_option('footerbdrcol') ); ?>"/>
          	   <input type='button' class='pickcolor button-secondary' value='Select Color'>
          	   <div style='z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;'></div>
          	</td>
          </tbody>
         	</table>
            <br>
            <table class="widefat">
             <thead>
              <tr>
               <th scope="col" colspan="2">Video Options</th>
              </tr>
             </thead>
              <tbody style="display: table-row-group;">
              <tr valign="top"><td width="350px"><?php _e( 'Auto Generate Video Thumbnails', 'imwb_videopress' ); ?></td>
              <td>
              	<select id="imwb_videopress_theme_options[autogenthumbs]" class="regular-text" type="text" name="imwb_videopress_theme_options[autogenthumbs]" />
              	<?php 
              	 foreach ($yesno_options as $key => $value) {
                     $selected = (imwb_videopress_get_option('autogenthumbs') == $key) ? " selected" : "";
              	    echo "<option value='{$key}'{$selected}>{$value['label']}</option>";
              	 }
              	?>
              	</select>
              </td>
              </tr>
               <tr valign="top"><td width="350px"><?php _e( 'Save Video Thumbnails To Media Library', 'imwb_videopress' ); ?></td>
               <td>
               	<select id="imwb_videopress_theme_options[storethumbs]" class="regular-text" type="text" name="imwb_videopress_theme_options[storethumbs]" />
               	<?php 
               	 foreach ($yesno_options as $key => $value) {
                      $selected = (imwb_videopress_get_option('storethumbs') == $key) ? " selected" : "";
               	    echo "<option value='{$key}'{$selected}>{$value['label']}</option>";
               	 }
               	?>
               	</select>
               </td>
               </tr>              
            		<tr valign="top"><td width="350px"><?php _e( 'Autoplay Videos', 'imwb_videopress' ); ?></td>
                  <td>
                  	<select id="imwb_videopress_theme_options[autoplay]" class="regular-text" type="text" name="imwb_videopress_theme_options[autoplay]" />
                  	<?php 
                  	 foreach ($yesno_options as $key => $value) {
                         $selected = (imwb_videopress_get_option('autoplay') == $key) ? " selected" : "";
                  	    echo "<option value='{$key}'{$selected}>{$value['label']}</option>";
                  	 }
                  	?>
                  	</select>
                  </td>
            		</tr>
            		</tr>              
         			<tr valign="top"><td width="350px"><?php _e( 'Activate modest branding on YouTube Videos', 'imwb_videopress' ); ?></td>
         		   <td>
         		   	<select id="imwb_videopress_theme_options[ytmodestbrand]" class="regular-text" type="text" name="imwb_videopress_theme_options[ytmodestbrand]" />
         		   	<?php 
         		   	 foreach ($yesno_options as $key => $value) {
         		          $selected = (imwb_videopress_get_option('ytmodestbrand') == $key) ? " selected" : "";
         		   	    echo "<option value='{$key}'{$selected}>{$value['label']}</option>";
         		   	 }
         		   	?>
         		   	</select>
         		   </td>
         			</tr>
             </tbody>
            	</table>         	
         	
         	
			<p class="submit">
				<input type="submit" class="button-primary" value="<?php _e( 'Save Options', 'imwb_videopress' ); ?>" />
			</p>
		</form>
   	<iframe src="http://imwealthbuilders.com/wp_squeeze/promote.php?aid=0" width="815px" height="800px"></iframe>
	</div>
  </div>
	<?php
}

/**
 * Sanitize and validate input. Accepts an array, return a sanitized array.
 */

function imwb_videopress_theme_options_validate( $input ) {
   $output = imwb_videopress_get_default_theme_options();

   foreach ($input as $key => $value) {
      if($key == "postchars") 
         $input[$key] = is_numeric($value) ? $value : 100;
      else if($key == "excludepages")  
         $input[$key] = implode(',', $value);
      else if($key == "excludecats")  
         $input[$key] = implode(',', $value);
          
		$output[$key] = trim($input[$key]);
	}

  	return $output;
 }


// See if were saving options
if(isset($_REQUEST['page']) && $_REQUEST['page'] == 'imwb_videopress_theme_options' && isset($_REQUEST['action']) && $_REQUEST['action'] == 'update') {

   // Deal with file uploads
   // favicon
   if ((($_FILES["favicon_img"]["type"] == "image/gif")
     || ($_FILES["favicon_img"]["type"] == "image/jpeg")
     || ($_FILES["favicon_img"]["type"] == "image/png")
     || ($_FILES["favicon_img"]["type"] == "image/jpeg")
     || ($_FILES["favicon_img"]["type"] == "image/pjpeg")
     || ($_FILES["favicon_img"]["type"] == "image/x-icon"))
     && ($_FILES["favicon_img"]["size"] > 0) &&  ($_FILES["favicon_img"]["error"] == 0))
   {
   	  $path = wp_upload_dir();
   	  if( !file_exists(  $path['path'] ) )
   	  {
   			mkdir(  $path['path'] );  
   	  }
   	  $logopath=  $path['path'] . "/" . $_FILES["favicon_img"]["name"];
   	  if( file_exists(  $logopath ) )
   	  {
   			unlink( $logopath); 
   	  }
   
        move_uploaded_file( $_FILES["favicon_img"]["tmp_name"],  $logopath);
   	  $_REQUEST['imwb_videopress_theme_options']['faviconurl'] =  $path['url'] . "/" . $_FILES["favicon_img"]["name"] ;
  }
  
   // Save options
   $updatedOptions = imwb_videopress_theme_options_validate($_REQUEST['imwb_videopress_theme_options']);
   update_option('imwb_videopress_theme_options', $updatedOptions);
   
}
?>